[kde-doc-english] [kdelibs/frameworks] /: Rename meinproc4 to meinproc5
Nicolas Lécureuil
neoclust at mageia.org
Mon Jul 1 08:02:14 UTC 2013
Git commit 9c79b35f6f145270cc77b8b6729d81c76b28dfee by Nicolas Lécureuil.
Committed on 28/06/2013 at 11:06.
Pushed by nlecureuil into branch 'frameworks'.
Rename meinproc4 to meinproc5
M +3 -15 KDELibs4Config.cmake
M +1 -1 doc/CMakeLists.txt
M +1 -1 doc/TODO
M +1 -1 doc/checkXML/man-checkXML.1.docbook
D +0 -1 doc/meinproc4/CMakeLists.txt
A +1 -0 doc/meinproc5/CMakeLists.txt
R +8 -8 doc/meinproc5/man-meinproc5.8.docbook [from: doc/meinproc4/man-meinproc4.8.docbook - 092% similarity]
M +12 -12 staging/kdoctools/KDocToolsMacros.cmake
M +1 -1 staging/kdoctools/checkXML.in.cmake
M +10 -10 staging/kdoctools/src/CMakeLists.txt
http://commits.kde.org/kdelibs/9c79b35f6f145270cc77b8b6729d81c76b28dfee
diff --git a/KDELibs4Config.cmake b/KDELibs4Config.cmake
index e1e5d09..2808a07 100644
--- a/KDELibs4Config.cmake
+++ b/KDELibs4Config.cmake
@@ -38,7 +38,7 @@
# The following variables are defined for the various tools required to
# compile KDE software:
#
-# KDE4_MEINPROC_EXECUTABLE - the meinproc4 executable
+# KDE4_MEINPROC_EXECUTABLE - the meinproc5 executable
# KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets executable
#
# The following variables point to the location of the KDE libraries,
@@ -253,18 +253,6 @@
# Installs all png and svgz files in the current directory to the icon
# directory given in path, in the subdirectory for the given icon theme.
#
-# KDE4_CREATE_HANDBOOK( docbookfile [INSTALL_DESTINATION installdest] [SUBDIR subdir])
-# Create the handbook from the docbookfile (using meinproc4)
-# The resulting handbook will be installed to <installdest> when using
-# INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
-# SUBDIR <subdir> is specified.
-#
-# KDE4_CREATE_MANPAGE( docbookfile section )
-# Create the manpage for the specified section from the docbookfile (using meinproc4)
-# The resulting manpage will be installed to <installdest> when using
-# INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
-# SUBDIR <subdir> is specified.
-#
# KDE4_INSTALL_AUTH_ACTIONS( HELPER_ID ACTIONS_FILE )
# This macro generates an action file, depending on the backend used, for applications using KAuth.
# It accepts the helper id (the DBUS name) and a file containing the actions (check kdelibs/kdecore/auth/example
@@ -463,10 +451,10 @@ include(${CMAKE_CURRENT_LIST_DIR}/KDELibs4ToolsTargets.cmake)
# get the build CONFIGURATIONS which were exported in this file, and use just the first
# of them to get the location of the installed executables
-get_target_property(_importedConfigurations ${KDE4_TARGET_PREFIX}meinproc4 IMPORTED_CONFIGURATIONS )
+get_target_property(_importedConfigurations ${KDE4_TARGET_PREFIX}meinproc5 IMPORTED_CONFIGURATIONS )
list(GET _importedConfigurations 0 _firstConfig)
-get_target_property(KDE4_MEINPROC_EXECUTABLE ${KDE4_TARGET_PREFIX}meinproc4 LOCATION_${_firstConfig})
+get_target_property(KDE4_MEINPROC_EXECUTABLE ${KDE4_TARGET_PREFIX}meinproc5 LOCATION_${_firstConfig})
get_target_property(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${KDE4_TARGET_PREFIX}makekdewidgets LOCATION_${_firstConfig})
# Include the Sonnet targets, they are needed by the imported kdeui target (included via KDELibs4LibraryTargets.cmake)
diff --git a/doc/CMakeLists.txt b/doc/CMakeLists.txt
index bdec716..02adcef 100644
--- a/doc/CMakeLists.txt
+++ b/doc/CMakeLists.txt
@@ -9,7 +9,7 @@ if (NOT WIN32)
add_subdirectory( kdeinit5 )
add_subdirectory( kdeoptions )
add_subdirectory( makekdewidgets )
- add_subdirectory( meinproc4 )
+ add_subdirectory( meinproc5 )
add_subdirectory( sonnet )
add_subdirectory( qtoptions )
add_subdirectory( kde4support )
diff --git a/doc/TODO b/doc/TODO
index 9f099da..5685dce 100644
--- a/doc/TODO
+++ b/doc/TODO
@@ -4,7 +4,7 @@ docs we need to write (handbook and manpages):
<DONE> kconfig_compiler
<DONE> preparetips
<DONE> makekdewidgets
-<DONE> meinproc4
+<DONE> meinproc5
<DONE> checkXML
<DONE> kcookiejar4
<DONE> kjs
diff --git a/doc/checkXML/man-checkXML.1.docbook b/doc/checkXML/man-checkXML.1.docbook
index 28eab3f..2bfb3f3 100644
--- a/doc/checkXML/man-checkXML.1.docbook
+++ b/doc/checkXML/man-checkXML.1.docbook
@@ -38,6 +38,6 @@ documentation.</para>
<refsect1>
<title>See Also</title>
-<para>meinproc4(1) xmllint(1)</para>
+<para>meinproc5(1) xmllint(1)</para>
</refsect1>
</refentry>
diff --git a/doc/meinproc4/CMakeLists.txt b/doc/meinproc4/CMakeLists.txt
deleted file mode 100644
index 95e358d..0000000
--- a/doc/meinproc4/CMakeLists.txt
+++ /dev/null
@@ -1 +0,0 @@
-kdoctools_create_manpage(man-meinproc4.8.docbook 8 INSTALL_DESTINATION ${MAN_INSTALL_DIR})
diff --git a/doc/meinproc5/CMakeLists.txt b/doc/meinproc5/CMakeLists.txt
new file mode 100644
index 0000000..858123d
--- /dev/null
+++ b/doc/meinproc5/CMakeLists.txt
@@ -0,0 +1 @@
+kdoctools_create_manpage(man-meinproc5.8.docbook 8 INSTALL_DESTINATION ${MAN_INSTALL_DIR})
diff --git a/doc/meinproc4/man-meinproc4.8.docbook b/doc/meinproc5/man-meinproc5.8.docbook
similarity index 92%
rename from doc/meinproc4/man-meinproc4.8.docbook
rename to doc/meinproc5/man-meinproc5.8.docbook
index 8f353bd..77799b4 100644
--- a/doc/meinproc4/man-meinproc4.8.docbook
+++ b/doc/meinproc5/man-meinproc5.8.docbook
@@ -40,12 +40,12 @@ Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man
</refentryinfo>
<refmeta>
-<refentrytitle><command>meinproc4</command></refentrytitle>
+<refentrytitle><command>meinproc5</command></refentrytitle>
<manvolnum>8</manvolnum>
</refmeta>
<refnamediv>
-<refname><command>meinproc4</command></refname>
+<refname><command>meinproc5</command></refname>
<refpurpose>&kde; translator for XML</refpurpose>
</refnamediv>
@@ -53,7 +53,7 @@ Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man
<title>Synopsis</title>
<cmdsynopsis>
-<command>meinproc4</command>
+<command>meinproc5</command>
<arg choice="opt">--help</arg>
<arg choice="opt">Generic-options</arg>
@@ -81,7 +81,7 @@ Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man
<refsect1>
<title>Description</title>
-<para><command>meinproc4</command> converts DocBook files to HTML.
+<para><command>meinproc5</command> converts DocBook files to HTML.
</para>
</refsect1>
@@ -177,7 +177,7 @@ Create a cache file for the document
<listitem>
<para>Check the document for validity</para>
<screen>The output can be a bit daunting, since one small mistake can cause a cascade of errors.
-The trick is to look at the first error, fix that error, save the file, and run <command>meinproc4</command> again.
+The trick is to look at the first error, fix that error, save the file, and run <command>meinproc5</command> again.
</screen>
</listitem>
</varlistentry>
@@ -241,9 +241,9 @@ Set parameters to pass to the stylesheet.
<refsect1>
<title>Usage</title>
<para>
-The most common way to run <command>meinproc4</command> is simply as
+The most common way to run <command>meinproc5</command> is simply as
<literallayout>
-<userinput><command>meinproc4</command> <replaceable>docbook-file</replaceable>
+<userinput><command>meinproc5</command> <replaceable>docbook-file</replaceable>
</userinput>
</literallayout>
where <replaceable>docbook-file</replaceable> is usually index.docbook.
@@ -253,7 +253,7 @@ Note that these pages are only viewable in KDE-based browsers (like Konqueror).
<para>
If you need to view the HTML output in another browser (for example, if you're placing it on line), use
<literallayout>
-<userinput><command>meinproc4</command> --stylesheet <replaceable>stylesheet-name</replaceable> <replaceable>docbook-file</replaceable>
+<userinput><command>meinproc5</command> --stylesheet <replaceable>stylesheet-name</replaceable> <replaceable>docbook-file</replaceable>
</userinput>
</literallayout>
where <replaceable>stylesheet-name</replaceable> is the full path to one of the XSL
diff --git a/staging/kdoctools/checkXML.in.cmake b/staging/kdoctools/checkXML.in.cmake
index 92d9a62..d7a57c7 100644
--- a/staging/kdoctools/checkXML.in.cmake
+++ b/staging/kdoctools/checkXML.in.cmake
@@ -2,5 +2,5 @@
prefix=${CMAKE_INSTALL_PREFIX}
exec_prefix=${CMAKE_INSTALL_PREFIX}/bin
-exit `${CMAKE_INSTALL_PREFIX}/bin/meinproc4 --check --stdout $@ > /dev/null`
+exit `${CMAKE_INSTALL_PREFIX}/bin/meinproc5 --check --stdout $@ > /dev/null`
diff --git a/staging/kdoctools/src/CMakeLists.txt b/staging/kdoctools/src/CMakeLists.txt
index 713d2a9..ab10171 100644
--- a/staging/kdoctools/src/CMakeLists.txt
+++ b/staging/kdoctools/src/CMakeLists.txt
@@ -72,25 +72,25 @@ set_source_files_properties(xslt.cpp PROPERTIES COMPILE_FLAGS -DSIMPLE_XSLT )
# The cross compiling parts are commented out on purpose. Alex
# if (CMAKE_CROSSCOMPILING)
-# set(IMPORT_MEINPROC4_EXECUTABLE "${KDE_HOST_TOOLS_PATH}/ImportMeinProc4Executable.cmake" CACHE FILEPATH "Point it to the export file of meinproc4 from a native build")
+# set(IMPORT_MEINPROC4_EXECUTABLE "${KDE_HOST_TOOLS_PATH}/ImportMeinProc4Executable.cmake" CACHE FILEPATH "Point it to the export file of meinproc5 from a native build")
# include(${IMPORT_MEINPROC4_EXECUTABLE})
#
# else (CMAKE_CROSSCOMPILING)
set(meinproc_SRCS meinproc.cpp meinproc_common.cpp xslt.cpp xslt_kde.cpp )
- kde4_add_executable(meinproc4 NOGUI ${meinproc_SRCS})
+ kde4_add_executable(meinproc5 NOGUI ${meinproc_SRCS})
- target_link_libraries(meinproc4 kdeqt5staging ki18n ${KArchive_LIBRARIES} ${LIBXML2_LIBRARIES} ${LIBXSLT_LIBRARIES} ${LIBXSLT_EXSLT_LIBRARIES} )
+ target_link_libraries(meinproc5 kdeqt5staging ki18n ${KArchive_LIBRARIES} ${LIBXML2_LIBRARIES} ${LIBXSLT_LIBRARIES} ${LIBXSLT_EXSLT_LIBRARIES} )
- add_dependencies(meinproc4 docbookl10nhelper)
+ add_dependencies(meinproc5 docbookl10nhelper)
# "export" this target too so we can use the LOCATION property of the imported target in
# FindKDE4Internal.cmake to get the full path to the installed executable instead of using FIND_PROGRAM(), Alex
- install(TARGETS meinproc4 EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS})
+ install(TARGETS meinproc5 EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS})
# # export this binary for cross-compilation
-# export(TARGETS meinproc4 FILE ${CMAKE_BINARY_DIR}/ImportMeinProc4Executable.cmake)
+# export(TARGETS meinproc5 FILE ${CMAKE_BINARY_DIR}/ImportMeinProc4Executable.cmake)
#
# endif (CMAKE_CROSSCOMPILING)
@@ -101,13 +101,13 @@ set_source_files_properties(xslt.cpp PROPERTIES COMPILE_FLAGS -DSIMPLE_XSLT )
if (NOT CMAKE_CROSSCOMPILING)
set(meinproc_qt_SRCS meinproc_simple.cpp meinproc_common.cpp xslt.cpp )
- kde4_add_executable(meinproc4_simple NOGUI ${meinproc_qt_SRCS})
+ kde4_add_executable(meinproc5_simple NOGUI ${meinproc_qt_SRCS})
- target_link_libraries(meinproc4_simple kdeqt5staging Qt5::Core ${LIBXML2_LIBRARIES} ${LIBXSLT_LIBRARIES} ${LIBXSLT_EXSLT_LIBRARIES})
+ target_link_libraries(meinproc5_simple kdeqt5staging Qt5::Core ${LIBXML2_LIBRARIES} ${LIBXSLT_LIBRARIES} ${LIBXSLT_EXSLT_LIBRARIES})
- add_dependencies(meinproc4_simple docbookl10nhelper)
+ add_dependencies(meinproc5_simple docbookl10nhelper)
- install(TARGETS meinproc4_simple ${INSTALL_TARGETS_DEFAULT_ARGS})
+ install(TARGETS meinproc5_simple ${INSTALL_TARGETS_DEFAULT_ARGS})
endif (NOT CMAKE_CROSSCOMPILING)
More information about the kde-doc-english
mailing list
diff --git a/staging/kdoctools/KDocToolsMacros.cmake b/staging/kdoctools/KDocToolsMacros.cmake
index e84fcb9..5f4a7a6 100644
--- a/staging/kdoctools/KDocToolsMacros.cmake
+++ b/staging/kdoctools/KDocToolsMacros.cmake
@@ -5,18 +5,18 @@
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
# KDOCTOOLS_CREATE_HANDBOOK( docbookfile [INSTALL_DESTINATION installdest] [SUBDIR subdir])
# Create the handbook from the docbookfile (using meinproc4)
# The resulting handbook will be installed to <installdest> when using
# INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
# SUBDIR <subdir> is specified.
#
# KDOCTOOLS_CREATE_MANPAGE( docbookfile section )
# Create the manpage for the specified section from the docbookfile (using meinproc4)
# The resulting manpage will be installed to <installdest> when using
# INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
# SUBDIR <subdir> is specified.
#
-# KDOCTOOLS_MEINPROC_EXECUTABLE - the meinproc4 executable
+# KDOCTOOLS_MEINPROC_EXECUTABLE - the meinproc5 executable
#
# KDE4_SERIALIZE_TOOL - wrapper to serialize potentially resource-intensive commands during
# parallel builds (set to 'icecc' when using icecream)
@@ -25,17 +25,17 @@
if (WIN32)
# CMAKE_CFG_INTDIR is the output subdirectory created e.g. by XCode and MSVC
if (NOT WINCE)
- set(KDOCTOOLS_MEINPROC_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4 )
+ set(KDOCTOOLS_MEINPROC_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc5 )
else (NOT WINCE)
- set(KDOCTOOLS_MEINPROC_EXECUTABLE ${HOST_BINDIR}/${CMAKE_CFG_INTDIR}/meinproc4 )
+ set(KDOCTOOLS_MEINPROC_EXECUTABLE ${HOST_BINDIR}/${CMAKE_CFG_INTDIR}/meinproc5 )
endif(NOT WINCE)
- set(KDOCTOOLS_MEINPROC_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4 )
+ set(KDOCTOOLS_MEINPROC_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc5 )
else (WIN32)
- set(KDOCTOOLS_MEINPROC_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/../staging/kdoctools/src/meinproc4${CMAKE_EXECUTABLE_SUFFIX}.shell )
+ set(KDOCTOOLS_MEINPROC_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/../staging/kdoctools/src/meinproc5${CMAKE_EXECUTABLE_SUFFIX}.shell )
endif (WIN32)
-set( _KDOCTOOLS_MEINPROC_EXECUTABLE_DEP meinproc4)
+set( _KDOCTOOLS_MEINPROC_EXECUTABLE_DEP meinproc5)
if(KDE4_SERIALIZE_TOOL)
# parallel build with many meinproc invocations can consume a huge amount of memory
@@ -58,9 +58,9 @@ macro (KDOCTOOLS_CREATE_HANDBOOK _docbook)
file(GLOB _docs *.docbook)
# if (CMAKE_CROSSCOMPILING)
-# set(IMPORT_MEINPROC4_EXECUTABLE "${KDE_HOST_TOOLS_PATH}/ImportMeinProc4Executable.cmake" CACHE FILEPATH "Point it to the export file of meinproc4 from a native build")
+# set(IMPORT_MEINPROC4_EXECUTABLE "${KDE_HOST_TOOLS_PATH}/ImportMeinProc4Executable.cmake" CACHE FILEPATH "Point it to the export file of meinproc5 from a native build")
# include(${IMPORT_MEINPROC4_EXECUTABLE})
-# set(KDOCTOOLS_MEINPROC_EXECUTABLE meinproc4)
+# set(KDOCTOOLS_MEINPROC_EXECUTABLE meinproc5)
# endif (CMAKE_CROSSCOMPILING)
add_custom_command(OUTPUT ${_doc}
@@ -135,9 +135,9 @@ macro (KDOCTOOLS_CREATE_MANPAGE _docbook _section)
endif (_kdeBootStrapping)
# if (CMAKE_CROSSCOMPILING)
-# set(IMPORT_MEINPROC4_EXECUTABLE "${KDE_HOST_TOOLS_PATH}/ImportMeinProc4Executable.cmake" CACHE FILEPATH "Point it to the export file of meinproc4 from a native build")
+# set(IMPORT_MEINPROC4_EXECUTABLE "${KDE_HOST_TOOLS_PATH}/ImportMeinProc4Executable.cmake" CACHE FILEPATH "Point it to the export file of meinproc5 from a native build")
# include(${IMPORT_MEINPROC4_EXECUTABLE})
-# set(KDOCTOOLS_MEINPROC_EXECUTABLE meinproc4)
+# set(KDOCTOOLS_MEINPROC_EXECUTABLE meinproc5)
# endif (CMAKE_CROSSCOMPILING)
add_custom_command(OUTPUT ${_outdoc}
@@ -5,18 +5,18 @@
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
# KDOCTOOLS_CREATE_HANDBOOK( docbookfile [INSTALL_DESTINATION installdest] [SUBDIR subdir])
-# Create the handbook from the docbookfile (using meinproc4)
+# Create the handbook from the docbookfile (using meinproc5)
# The resulting handbook will be installed to <installdest> when using
# INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
@@ -5,18 +5,18 @@
#
# KDOCTOOLS_CREATE_MANPAGE( docbookfile section )
-# Create the manpage for the specified section from the docbookfile (using meinproc4)
+# Create the manpage for the specified section from the docbookfile (using meinproc5)
# The resulting manpage will be installed to <installdest> when using
# INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if